summaryrefslogtreecommitdiffhomepage
path: root/src/rlgl.h
diff options
context:
space:
mode:
authorRay <[email protected]>2015-11-04 18:33:46 +0100
committerRay <[email protected]>2015-11-04 18:33:46 +0100
commit76024b5036f060a19a1a2eea49c401d6db81cda8 (patch)
tree32b2a85a37dbc12d303467d7fb6669ee11b6f47f /src/rlgl.h
parent002dacef4091de16731961c9b85363097d14106b (diff)
downloadraylib-76024b5036f060a19a1a2eea49c401d6db81cda8.tar.gz
raylib-76024b5036f060a19a1a2eea49c401d6db81cda8.zip
Added some texture functionality (view details)
LoadTextureEx() - Simplified parameters UpdateTexture() - Added, allows updating GPU texture data
Diffstat (limited to 'src/rlgl.h')
-rw-r--r--src/rlgl.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/rlgl.h b/src/rlgl.h
index 272b245e..ce823d97 100644
--- a/src/rlgl.h
+++ b/src/rlgl.h
@@ -242,7 +242,8 @@ void rlglClose(void); // De-init rlgl
void rlglDraw(void); // Draw VAO/VBO
void rlglInitGraphics(int offsetX, int offsetY, int width, int height); // Initialize Graphics (OpenGL stuff)
-unsigned int rlglLoadTexture(void *data, int width, int height, int textureFormat, int mipmapCount); // Load in GPU OpenGL texture
+unsigned int rlglLoadTexture(void *data, int width, int height, int textureFormat, int mipmapCount); // Load texture in GPU
+void rlglUpdateTexture(unsigned int id, int width, int height, int format, void *data); // Update GPU texture with new data
void rlglGenerateMipmaps(unsigned int textureId); // Generate mipmap data for selected texture
// NOTE: There is a set of shader related functions that are available to end user,